.. _20160217_mission_amendment:

========================================
 2016-02-17 OpenStack Mission amendment
========================================

  .. note::

    This is an update to :ref:`20160106_mission_amendment` in response to
    feedback from the OpenStack Foundation Board of Directors and the following
    `discussion on the foundation mailing list
    <http://lists.openstack.org/pipermail/foundation/2016-February/002263.html>`_.

The OpenStack Mission is a critical statement which defines what the
OpenStack project is about and the goals we, as a community, aspire to reach.
As such, modifying it requires buy-in from all sides of the project
governance.

As of today, the OpenStack Mission is the following::

  to produce the ubiquitous Open Source Cloud Computing platform that will
  meet the needs of public and private clouds regardless of size, by being
  simple to implement and massively scalable.

It appears that the current statement fails to mention two critical elements:
promoting interoperability and serving end users. Those two themes are already
recognized as key goals of the OpenStack Community, but yet they are missing
from our mission statement.

Therefore, the Technical Committee suggests that we make a small change to
the OpenStack Mission statement to include those two elements. It suggests
the adoption of the following wording::

  To produce a ubiquitous Open Source Cloud Computing platform that is
  easy to use, simple to implement, interoperable between deployments,
  works well at all scales, and meets the needs of users and operators of
  both public and private clouds.
